ENABLED_MODULES = [
    'thyme',
    'gitmodule',
    'toggl',
    'taiga',
    'jira',
    'slack',
]

TIMEZONE = 'Europe/Helsinki'

TESTING = False

UI_SETTINGS = {
    'toggl': {
        'global': '#E01A22'
    },
    'thyme': {
        'global': '#1aef65'
    },
    'gitmodule': {
        'global': '#F44D27'
    },
    'slack': {
        'global': '#4A154B'
    }
}

TOGGL = {
    'global': {
        'API_KEY': '779e369d872d75354fa05f5eb7d0b7dc'
    },
    'outdoor': {
        'NAME': 'Scandinavian Outdoor',
        'PROJECTS': {
            'Verkkokauppakehitys': 'default',
        }
    },
    'storm': {
        'NAME': 'Storm',
        'PROJECTS': {
            'Verkkokauppakehitys': 'default',
        }
    },
    'myssy': {
        'NAME': 'Myssyfarmi',
        'PROJECTS': {
            'Verkkokauppakehitys': 'default',
        }
    }
}

GIT = {
    'global': {
        'EMAILS': ['eero.vilpponen@gmail.com', 'eero.vilpponen@protecomp.fi'],
    },
    'outdoor': {
        'REPOS': ['/home/eero/Documents/outdoor/sos',
                  '/home/eero/Documents/outdoor/tilhi', '/home/eero/Documents/outdoor/soi',
                  '/home/eero/Documents/outdoor/soi/shared-apps']
    },
    'storm': {
        'REPOS': ['/home/eero/Documents/storm']
    },
    'myssy': {
        'REPOS': ['/home/eero/Documents/myssyfarmi']
    },
    'cloudprice': {
        'REPOS': ['/home/eero/Documents/cloudprice']
    },
}

JIRA = {
    'outdoor': {
        'CREDENTIALS': ('eero.vilpponen@protecomp.fi', '.A8Ai-ngyfhXu7F-r-BC'),
        'URL': 'https://scandinavianoutdoor.atlassian.net',
        'PROJECT_KEY': 'DEV',
    }
}

TAIGA = {
    'global': {
        'CREDENTIALS': ['eerovilpponen', 'pru2-.34Ndw*WMjqT24w']
    },
    'storm': {
        'project_slug': 'msvilp-storm'
    },
    'myssy': {
        'project_slug': 'msvilp-myssyfarmi'
    }
}

THYME = {
    'global': {
        'DIR': '/home/eero/Documents/thyme',
        'IDLE': 900,
        'CUTOFF': 300,
    }
}

SLACK = {
    'global': {
        'API_KEY': 'xoxp-13389763879-213139729830-637577337329-5befc4931ec28f32c6b0b2769d0a0cfa',
        'USER_ID': 'U6943MFQE',
    },
    'outdoor': {
        'API_KEY': 'xoxp-13373711861-338515366999-643893862037-93e50147016e9a20d1d81323625343dc',
        'USER_ID': 'U9YF5ASVD'
    },
}

# from tracklater.test_settings import *  # noqa




# Rename to `user_settings.py` and edit to your liking.

TESTING = False

ENABLED_MODULES = [
    'thyme',
    'gitmodule',
    'toggl',
    'taiga',
    'jira',
    'slack'
]

UI_SETTINGS = {
    'toggl': {
        'global': '#E01A22'
    },
    'thyme': {
        'global': '#1aef65'
    },
    'gitmodule': {
        'global': '#F44D27'
    },
    'slack': {
        'global': '#4A154B'
    }
}

# Toggl module supports a single login using an api key.

TOGGL = {
    'global': {
        'API_KEY': 'your-api-key'
    },
    'group1': {
        # NAME Must match the client name on toggl
        'NAME': 'First Group',
        'PROJECTS': {
            # PROJECTS Keys must match the project name on toggl.
            # Values contain a project type, currently unused.
            'Development': 'default',
            'Bug fixing': 'bug',
        }
    },
    'group2': {
        'NAME': 'Second Group',
        'PROJECTS': {
            'Development': 'default',
            'Bug fixing': 'default',
        }
    }
}

GIT = {
    'global': {
        # Only commits made by users with EMAILS will be shown
        'EMAILS': ['firstname.lastname@email.com'],
    },
    'group1': {
        # Full path to the git repo
        'REPOS': ['/full/path/to/group1/repo']
    },
    'group2': {
        'REPOS': ['/full/path/to/group2/repo']
    },
}

JIRA = {
    'group1': {
        # Each group must have these settings
        'CREDENTIALS': ('username', 'password'),
        'URL': 'https://group1.atlassian.net',
        'PROJECT_KEY': 'DEV',
    }
}

TAIGA = {
    'global': {
        'CREDENTIALS': ['username', 'password']
    },
    'group2': {
        # project_slug can be found in the URL
        'project_slug': 'username-group2'
    }
}

THYME = {
    'global': {
        # Directory containing the json files generated by thyme
        'DIR': '/full/path/to/thyme/dir',
    }
}

SLACK = {
    # Each group should contain a workspace to match all messager to a group
    'global': {
        # Global catch-all workspace for all groups
        'API_KEY': 'legacy-slack-api-key-global',
        'USER_ID': 'your-user-id',
    },
    'group2': {
        # Messages in this workspace will be matched to group2
        'API_KEY': 'legacy-slack-api-key-group2',
        'USER_ID': 'your-user-id',
    }
}



import logging
logger = logging.getLogger(__name__)


try:
    from tracklater.user_settings import *  # noqa
except ImportError:
    from tracklater.test_settings import *  # noqa
    logger.error("No user settings file! Create one called user_settings.py")


def helper(module, key, group='global', default=None):
    # Try given group first
    if group in globals()[module]:
        _tmp_dict = globals()[module][group]
        if key in _tmp_dict:
            return _tmp_dict[key]
    # Try with 'global' group
    if 'global' in globals()[module]:
        _tmp_dict = globals()[module]['global']
        if key in _tmp_dict:
            return _tmp_dict[key]
    if default:
        return default

    raise KeyError('No setting "{}" for module {} found'.format(key, module))
